@@ -24,6 +24,7 @@ from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
 
 
 class NodesClient(NamespacedClient):
+
     @_rewrite_parameters()
     async def clear_repositories_metering_archive(
         self,
@@ -36,9 +37,10 @@ class NodesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Removes the archived repositories metering information present in the cluster.
+        You can use this API to clear the archived repositories metering information
+        in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/clear-repositories-metering-archive-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/clear-repositories-metering-archive-api.html>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information. All the nodes selective options are explained [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster.html#cluster-nodes).
@@ -49,7 +51,11 @@ class NodesClient(NamespacedClient):
             raise ValueError("Empty value passed for parameter 'node_id'")
         if max_archive_version in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'max_archive_version'")
-        __path = f"/_nodes/{_quote(node_id)}/_repositories_metering/{_quote(max_archive_version)}"
+        __path_parts: t.Dict[str, str] = {
+            "node_id": _quote(node_id),
+            "max_archive_version": _quote(max_archive_version),
+        }
+        __path = f'/_nodes/{__path_parts["node_id"]}/_repositories_metering/{__path_parts["max_archive_version"]}'
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -61,7 +67,12 @@ class NodesClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
-            "DELETE", __path, params=__query, headers=__headers
+            "DELETE",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.clear_repositories_metering_archive",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -75,16 +86,21 @@ class NodesClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns cluster repositories metering information.
+        You can use the cluster repositories metering API to retrieve repositories metering
+        information in a cluster. This API exposes monotonically non-decreasing counters
+        and it’s expected that clients would durably store the information needed to
+        compute aggregations over a period of time. Additionally, the information exposed
+        by this API is volatile, meaning that it won’t be present after node restarts.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/get-repositories-metering-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-repositories-metering-api.html>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information. All the nodes selective options are explained [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster.html#cluster-nodes).
         """
         if node_id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'node_id'")
-        __path = f"/_nodes/{_quote(node_id)}/_repositories_metering"
+        __path_parts: t.Dict[str, str] = {"node_id": _quote(node_id)}
+        __path = f'/_nodes/{__path_parts["node_id"]}/_repositories_metering'
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -96,7 +112,12 @@ class NodesClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.get_repositories_metering_info",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -108,25 +129,24 @@ class NodesClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         ignore_idle_threads: t.Optional[bool] = None,
-        interval: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        interval: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         snapshots: t.Optional[int] = None,
         sort: t.Optional[
-            t.Union["t.Literal['block', 'cpu', 'gpu', 'mem', 'wait']", str]
+            t.Union[str, t.Literal["block", "cpu", "gpu", "mem", "wait"]]
         ] = None,
         threads: t.Optional[int] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         type: t.Optional[
-            t.Union["t.Literal['block', 'cpu', 'gpu', 'mem', 'wait']", str]
+            t.Union[str, t.Literal["block", "cpu", "gpu", "mem", "wait"]]
         ] = None,
     ) -> TextApiResponse:
         """
-        Returns information about hot threads on each node in the cluster.
+        This API yields a breakdown of the hot threads on each selected node in the cluster.
+        The output is plain text with a breakdown of each node’s top hot threads.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/cluster-nodes-hot-threads.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-nodes-hot-threads.html>`_
 
         :param node_id: List of node IDs or names used to limit returned information.
         :param ignore_idle_threads: If true, known idle threads (e.g. waiting in a socket
@@ -142,9 +162,12 @@ class NodesClient(NamespacedClient):
             the timeout expires, the request fails and returns an error.
         :param type: The type to sample.
         """
+        __path_parts: t.Dict[str, str]
         if node_id not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/hot_threads"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/hot_threads'
         else:
+            __path_parts = {}
             __path = "/_nodes/hot_threads"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
@@ -173,7 +196,12 @@ class NodesClient(NamespacedClient):
             __query["type"] = type
         __headers = {"accept": "text/plain"}
         return await self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.hot_threads",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -186,16 +214,14 @@ class NodesClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns information about nodes in the cluster.
+        Returns cluster nodes information.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/cluster-nodes-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-nodes-info.html>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information.
@@ -208,13 +234,18 @@ class NodesClient(NamespacedClient):
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         """
+        __path_parts: t.Dict[str, str]
         if node_id not in SKIP_IN_PATH and metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/{_quote(metric)}"
+            __path_parts = {"node_id": _quote(node_id), "metric": _quote(metric)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/{__path_parts["metric"]}'
         elif node_id not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_nodes/{__path_parts["node_id"]}'
         elif metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(metric)}"
+            __path_parts = {"metric": _quote(metric)}
+            __path = f'/_nodes/{__path_parts["metric"]}'
         else:
+            __path_parts = {}
             __path = "/_nodes"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
@@ -233,7 +264,12 @@ class NodesClient(NamespacedClient):
             __query["timeout"] = timeout
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.info",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters(
@@ -248,22 +284,25 @@ class NodesClient(NamespacedClient):
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
         secure_settings_password: t.Optional[str] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Reloads secure settings.
+        Reloads the keystore on nodes in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/secure-settings.html#reloadable-secure-settings>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/secure-settings.html#reloadable-secure-settings>`_
 
         :param node_id: The names of particular nodes in the cluster to target.
         :param secure_settings_password: The password for the Elasticsearch keystore.
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         """
+        __path_parts: t.Dict[str, str]
         if node_id not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/reload_secure_settings"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/reload_secure_settings'
         else:
+            __path_parts = {}
             __path = "/_nodes/reload_secure_settings"
         __query: t.Dict[str, t.Any] = {}
         __body: t.Dict[str, t.Any] = body if body is not None else {}
@@ -286,7 +325,13 @@ class NodesClient(NamespacedClient):
         if __body is not None:
             __headers["content-type"] = "application/json"
         return await self.perform_request(  # type: ignore[return-value]
-            "POST", __path, params=__query, headers=__headers, body=__body
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="nodes.reload_secure_settings",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -306,19 +351,17 @@ class NodesClient(NamespacedClient):
         include_segment_file_sizes: t.Optional[bool] = None,
         include_unloaded_segments: t.Optional[bool] = None,
         level: t.Optional[
-            t.Union["t.Literal['cluster', 'indices', 'shards']", str]
-        ] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+            t.Union[str, t.Literal["cluster", "indices", "shards"]]
         ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         types: t.Optional[t.Sequence[str]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns statistical information about nodes in the cluster.
+        Returns cluster nodes statistics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/cluster-nodes-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-nodes-stats.html>`_
 
         :param node_id: Comma-separated list of node IDs or names used to limit returned
             information.
@@ -349,21 +392,37 @@ class NodesClient(NamespacedClient):
         :param types: A comma-separated list of document types for the indexing index
             metric.
         """
+        __path_parts: t.Dict[str, str]
         if (
             node_id not in SKIP_IN_PATH
             and metric not in SKIP_IN_PATH
             and index_metric not in SKIP_IN_PATH
         ):
-            __path = f"/_nodes/{_quote(node_id)}/stats/{_quote(metric)}/{_quote(index_metric)}"
+            __path_parts = {
+                "node_id": _quote(node_id),
+                "metric": _quote(metric),
+                "index_metric": _quote(index_metric),
+            }
+            __path = f'/_nodes/{__path_parts["node_id"]}/stats/{__path_parts["metric"]}/{__path_parts["index_metric"]}'
         elif node_id not in SKIP_IN_PATH and metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/stats/{_quote(metric)}"
+            __path_parts = {"node_id": _quote(node_id), "metric": _quote(metric)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/stats/{__path_parts["metric"]}'
         elif metric not in SKIP_IN_PATH and index_metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/stats/{_quote(metric)}/{_quote(index_metric)}"
+            __path_parts = {
+                "metric": _quote(metric),
+                "index_metric": _quote(index_metric),
+            }
+            __path = (
+                f'/_nodes/stats/{__path_parts["metric"]}/{__path_parts["index_metric"]}'
+            )
         elif node_id not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/stats"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/stats'
         elif metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/stats/{_quote(metric)}"
+            __path_parts = {"metric": _quote(metric)}
+            __path = f'/_nodes/stats/{__path_parts["metric"]}'
         else:
+            __path_parts = {}
             __path = "/_nodes/stats"
         __query: t.Dict[str, t.Any] = {}
         if completion_fields is not None:
@@ -396,7 +455,12 @@ class NodesClient(NamespacedClient):
             __query["types"] = types
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.stats",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -409,12 +473,12 @@ class NodesClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns low-level information about REST actions usage on nodes.
+        Returns information on the usage of features.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/cluster-nodes-usage.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-nodes-usage.html>`_
 
         :param node_id: A comma-separated list of node IDs or names to limit the returned
             information; use `_local` to return information from the node you're connecting
@@ -424,13 +488,18 @@ class NodesClient(NamespacedClient):
         :param timeout: Period to wait for a response. If no response is received before
             the timeout expires, the request fails and returns an error.
         """
+        __path_parts: t.Dict[str, str]
         if node_id not in SKIP_IN_PATH and metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/usage/{_quote(metric)}"
+            __path_parts = {"node_id": _quote(node_id), "metric": _quote(metric)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/usage/{__path_parts["metric"]}'
         elif node_id not in SKIP_IN_PATH:
-            __path = f"/_nodes/{_quote(node_id)}/usage"
+            __path_parts = {"node_id": _quote(node_id)}
+            __path = f'/_nodes/{__path_parts["node_id"]}/usage'
         elif metric not in SKIP_IN_PATH:
-            __path = f"/_nodes/usage/{_quote(metric)}"
+            __path_parts = {"metric": _quote(metric)}
+            __path = f'/_nodes/usage/{__path_parts["metric"]}'
         else:
+            __path_parts = {}
             __path = "/_nodes/usage"
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
@@ -445,5 +514,10 @@ class NodesClient(NamespacedClient):
             __query["timeout"] = timeout
         __headers = {"accept": "application/json"}
         return await self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="nodes.usage",
+            path_parts=__path_parts,
         )
